@@ -62,8 +62,6 @@ typedef struct _WnckTaskClass   WnckTaskClass;
 #define DEFAULT_WIDTH 1
 #define DEFAULT_HEIGHT 48
 
-#define TIMEOUT_ACTIVATE 1000
-
 #define N_SCREEN_CONNECTIONS 5
 
 #define POINT_IN_RECT(xcoord, ycoord, rect) \
@@ -1942,7 +1940,7 @@ wnck_tasklist_activate_task_window     (WnckTask *task)
     }
   else
     {
-      if (task->was_active)
+      if (task->was_active || wnck_window_transient_is_active (task->window))
 	{
 	  task->was_active = FALSE;
 	  wnck_window_minimize (task->window);
@@ -2442,7 +2440,7 @@ wnck_task_drag_motion (GtkWidget          *widget,
 {
 
    if (task->button_activate == 0 && task->type == WNCK_TASK_WINDOW)
-       task->button_activate = g_timeout_add (TIMEOUT_ACTIVATE,
+       task->button_activate = g_timeout_add (WNCK_ACTIVATE_TIMEOUT,
                                               wnck_task_motion_timeout,
                                               task);
    gdk_drag_status (context,0,time);
