@@ -63,7 +63,8 @@ typedef enum
   WNCK_WINDOW_ACTION_MINIMIZE                = 1 << 12,
   WNCK_WINDOW_ACTION_UNMINIMIZE              = 1 << 13,
   WNCK_WINDOW_ACTION_MAXIMIZE                = 1 << 14,
-  WNCK_WINDOW_ACTION_UNMAXIMIZE              = 1 << 15
+  WNCK_WINDOW_ACTION_UNMAXIMIZE              = 1 << 15,
+  WNCK_WINDOW_ACTION_FULLSCREEN              = 1 << 16
 } WnckWindowActions;
 
 typedef enum
@@ -153,6 +154,7 @@ gboolean wnck_window_is_maximized              (WnckWindow *window);
 gboolean wnck_window_is_shaded                 (WnckWindow *window);
 gboolean wnck_window_is_skip_pager             (WnckWindow *window);
 gboolean wnck_window_is_skip_tasklist          (WnckWindow *window);
+gboolean wnck_window_is_fullscreen                 (WnckWindow *window);
 gboolean wnck_window_is_sticky                 (WnckWindow *window);
 gboolean wnck_window_demands_attention         (WnckWindow *window);
 
@@ -160,6 +162,8 @@ void wnck_window_set_skip_pager    (WnckWindow *window,
                                     gboolean skip);
 void wnck_window_set_skip_tasklist (WnckWindow *window,
                                     gboolean skip);
+void wnck_window_set_fullscreen (WnckWindow *window,
+                                 gboolean fullscreen);
 
 void wnck_window_close                   (WnckWindow *window,
 					  guint32     timestamp);
@@ -189,8 +193,9 @@ void     wnck_window_unpin     (WnckWindow *window);
 
 void     wnck_window_activate  (WnckWindow *window);
 gboolean wnck_window_is_active (WnckWindow *window);
+gboolean wnck_window_is_most_recently_activated (WnckWindow *window);
 void     wnck_window_activate_transient (WnckWindow *window);
-
+gboolean wnck_window_transient_is_active (WnckWindow *window);
 
 GdkPixbuf* wnck_window_get_icon      (WnckWindow *window);
 GdkPixbuf* wnck_window_get_mini_icon (WnckWindow *window);
